sdv.lite.tabular.TabularPreset
==============================

.. currentmodule:: sdv.lite.tabular

.. autoclass:: TabularPreset

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TabularPreset.__init__
      ~TabularPreset.fit
      ~TabularPreset.list_available_presets
      ~TabularPreset.load
      ~TabularPreset.sample
      ~TabularPreset.sample_conditions
      ~TabularPreset.sample_remaining_columns
      ~TabularPreset.save
   
   

   
   
   